summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2015-03-10 16:25:23 +0100
committerChristian Grothoff <christian@grothoff.org>2015-03-10 16:25:23 +0100
commite3b8f5117e8028f3183871ab0efb0c6f2ff959eb (patch)
tree06949248a0bbf5c35d988c4dc624e6f57a21c077
parentdaa5fbe3b755113d0a82b606976f68851e3a11dc (diff)
downloadexchange-e3b8f5117e8028f3183871ab0efb0c6f2ff959eb.tar.gz
exchange-e3b8f5117e8028f3183871ab0efb0c6f2ff959eb.tar.bz2
exchange-e3b8f5117e8028f3183871ab0efb0c6f2ff959eb.zip
remove redundant arg 'num_oldcoins/num_newcoins'
-rw-r--r--src/mint/taler-mint-httpd_db.c12
-rw-r--r--src/mint/taler-mint-httpd_db.h8
-rw-r--r--src/mint/taler-mint-httpd_refresh.c12
3 files changed, 8 insertions, 24 deletions
diff --git a/src/mint/taler-mint-httpd_db.h b/src/mint/taler-mint-httpd_db.h
index 91d40e44c..84e65eef2 100644
--- a/src/mint/taler-mint-httpd_db.h
+++ b/src/mint/taler-mint-httpd_db.h
@@ -114,14 +114,12 @@ struct MeltDetails
* @param refresh_session_pub public key of the refresh session
* @param client_signature signature of the client (matching @a refresh_session_pub)
* over the melting request
- * @param num_new_denoms number of entries in @a denom_pubs
+ * @param num_new_denoms number of entries in @a denom_pubs, size of y-dimension of @commit_coin array
* @param denum_pubs array of public denomination keys for the refresh (?)
- * @param coin_count number of entries in @a coin_public_infos and @ a coin_melt_details
+ * @param coin_count number of entries in @a coin_public_infos and @ a coin_melt_details, size of y-dimension of @commit_link array
* @param coin_public_infos information about the coins to melt
* @param coin_melt_details signatures and (residual) value of the respective coin should be melted
* @param kappa size of x-dimension of @commit_coin and @commit_link arrays
- * @param num_oldcoins size of y-dimension of @commit_coin array
- * @param num_newcoins size of y-dimension of @commit_link array
* @param commit_coin 2d array of coin commitments (what the mint is to sign
* once the "/refres/reveal" of cut and choose is done)
* @param commit_link 2d array of coin link commitments (what the mint is
@@ -141,8 +139,6 @@ TALER_MINT_db_execute_refresh_melt (struct MHD_Connection *connection,
const struct TALER_CoinPublicInfo *coin_public_infos,
const struct MeltDetails *coin_melt_details,
unsigned int kappa,
- unsigned int num_oldcoins,
- unsigned int num_newcoins,
struct RefreshCommitCoin *const* commit_coin,
struct RefreshCommitLink *const* commit_link);
diff --git a/src/mint/taler-mint-httpd_refresh.c b/src/mint/taler-mint-httpd_refresh.c
index db3edebe8..6c3cbbc71 100644
--- a/src/mint/taler-mint-httpd_refresh.c
+++ b/src/mint/taler-mint-httpd_refresh.c
@@ -145,16 +145,14 @@ request_json_check_signature (struct MHD_Connection *connection,
*
* @param connection the MHD connection to handle
* @param refresh_session_pub public key of the melt operation
- * @param num_new_denoms number of coins to be created
+ * @param num_new_denoms number of coins to be created, size of y-dimension of @commit_link array
* @param denom_pubs array of @a num_new_denoms keys
- * @param coin_count number of coins to be melted
+ * @param coin_count number of coins to be melted, size of y-dimension of @commit_coin array
* @param coin_public_infos array with @a coin_count entries about the coins
* @param coin_melt_details array with @a coin_count entries with melting details
* @param melt_sig_json signature affirming the overall melt operation
* @param commit_client_sig signature of the client over this commitment
* @param kappa size of x-dimension of @commit_coin and @commit_link arrays
- * @param num_oldcoins size of y-dimension of @commit_coin array
- * @param num_newcoins size of y-dimension of @commit_link array
* @param commit_coin 2d array of coin commitments (what the mint is to sign
* once the "/refres/reveal" of cut and choose is done)
* @param commit_link 2d array of coin link commitments (what the mint is
@@ -173,8 +171,6 @@ handle_refresh_melt_binary (struct MHD_Connection *connection,
const json_t *melt_sig_json,
const struct GNUNET_CRYPTO_EddsaSignature *commit_client_sig,
unsigned int kappa,
- unsigned int num_oldcoins,
- unsigned int num_newcoins,
struct RefreshCommitCoin *const* commit_coin,
struct RefreshCommitLink *const* commit_link)
@@ -274,8 +270,6 @@ handle_refresh_melt_binary (struct MHD_Connection *connection,
coin_public_infos,
coin_melt_details,
kappa,
- num_oldcoins,
- num_newcoins,
commit_coin,
commit_link);
}
@@ -669,8 +663,6 @@ handle_refresh_melt_json (struct MHD_Connection *connection,
melt_sig_json,
NULL /* FIXME: 3635! */,
kappa,
- num_oldcoins,
- num_newcoins,
commit_coin,
commit_link);
free_commit_coins (commit_coin, kappa, num_newcoins);
diff --git a/src/mint/taler-mint-httpd_db.c b/src/mint/taler-mint-httpd_db.c
index a4a03aba0..12e4f3e78 100644
--- a/src/mint/taler-mint-httpd_db.c
+++ b/src/mint/taler-mint-httpd_db.c
@@ -508,14 +508,12 @@ refresh_accept_melts (struct MHD_Connection *connection,
* @param refresh_session_pub public key of the refresh session
* @param client_signature signature of the client (matching @a refresh_session_pub)
* over the melting request
* @param num_new_denoms number of entries in @a denom_pubs
* @param denum_pubs public keys of the coins we want to withdraw in the end
- * @param coin_count number of entries in @a coin_public_infos and @a coin_melt_details
+ * @param coin_count number of entries in @a coin_public_infos and @a coin_melt_details, size of y-dimension of @commit_link array
* @param coin_public_infos information about the coins to melt
* @param coin_melt_details signatures and (residual) value of the respective coin should be melted
* @param kappa size of x-dimension of @commit_coin and @commit_link arrays
- * @param num_oldcoins size of y-dimension of @commit_link array
- * @param num_newcoins size of y-dimension of @commit_coin array
* @param commit_coin 2d array of coin commitments (what the mint is to sign
* once the "/refres/reveal" of cut and choose is done)
* @param commit_link 2d array of coin link commitments (what the mint is
@@ -534,8 +532,6 @@ TALER_MINT_db_execute_refresh_melt (struct MHD_Connection *connection,
const struct TALER_CoinPublicInfo *coin_public_infos,
const struct MeltDetails *coin_melt_details,
unsigned int kappa,
- unsigned int num_oldcoins,
- unsigned int num_newcoins,
struct RefreshCommitCoin *const* commit_coin,
struct RefreshCommitLink *const* commit_link)
{
@@ -611,7 +607,7 @@ TALER_MINT_db_execute_refresh_melt (struct MHD_Connection *connection,
for (i = 0; i < kappa; i++)
{
- for (j = 0; j < num_newcoins; j++)
+ for (j = 0; j < num_new_denoms; j++)
{
if (GNUNET_OK !=
TALER_MINT_DB_insert_refresh_commit_coin (db_conn,
@@ -627,7 +623,7 @@ TALER_MINT_db_execute_refresh_melt (struct MHD_Connection *connection,
}
for (i = 0; i < kappa; i++)
{
- for (j = 0; j < num_oldcoins; j++)
+ for (j = 0; j < coin_count; j++)
{
if (GNUNET_OK !=
TALER_MINT_DB_insert_refresh_commit_link (db_conn,
@@ -508,14 +508,12 @@ refresh_accept_melts (struct MHD_Connection *connection,
* @param client_signature signature of the client (matching @a refresh_session_pub)
* over the melting request
- * @param num_new_denoms number of entries in @a denom_pubs
+ * @param num_new_denoms number of entries in @a denom_pubs, size of y-dimension of @commit_coin array
* @param denum_pubs public keys of the coins we want to withdraw in the end